import { __awaiter, __decorate } from "tslib";
import { LifecycleMixin } from '@genesislcap/foundation-utils';
import { attr, customElement, FoundationElement, observable } from '@genesislcap/web-core';
import { FDC3 } from './fdc3';
/**
 * fdc3-channel-event
 * @internal
 */
let Fdc3ChannelEvent = class Fdc3ChannelEvent extends LifecycleMixin(FoundationElement) {
    constructor() {
        super(...arguments);
        this.sendEventOnChannel = (e) => __awaiter(this, void 0, void 0, function* () {
            let payload = e.detail.data || e.detail;
            if (this.mappingFunction && typeof this.mappingFunction === 'function') {
                payload = this.mappingFunction(payload);
            }
            if (this.channelName) {
                yield this.fdc3.broadcastOnChannel(this.channelName, this.channelType, payload);
            }
            else {
                yield this.fdc3.broadcastOnCurrentChannel(payload, this.channelType);
            }
        });
    }
    connectedCallback() {
        this.parentElement.addEventListener(this.eventName, this.sendEventOnChannel);
    }
    disconnectedCallback() {
        this.parentElement.removeEventListener(this.eventName, this.sendEventOnChannel);
    }
    deepClone() {
        const copy = super.deepClone();
        if (this.mappingFunction) {
            copy.mappingFunction = this.mappingFunction.bind(copy);
        }
        return copy;
    }
};
__decorate([
    FDC3
], Fdc3ChannelEvent.prototype, "fdc3", void 0);
__decorate([
    attr({ attribute: 'event-name' })
], Fdc3ChannelEvent.prototype, "eventName", void 0);
__decorate([
    attr({ attribute: 'channel-type' })
], Fdc3ChannelEvent.prototype, "channelType", void 0);
__decorate([
    attr({ attribute: 'channel-name' })
], Fdc3ChannelEvent.prototype, "channelName", void 0);
__decorate([
    observable
], Fdc3ChannelEvent.prototype, "mappingFunction", void 0);
Fdc3ChannelEvent = __decorate([
    customElement({
        name: 'fdc3-channel-event',
    })
], Fdc3ChannelEvent);
export { Fdc3ChannelEvent };
